@@ -1,15 +1,12 @@
-from airflow.hooks.base_hook import BaseHook
+from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator
-from airflow.utils import apply_defaults
 from botocore.config import Config
-
 import boto3
 
 
 class GlueCrawlerOperator(BaseOperator):
     template_fields = ('glue_crawler_name',)
 
-    @apply_defaults
     def __init__(
         self,
         glue_crawler_name,
@@ -310,7 +307,6 @@ class AWSGlueJobOperator(BaseOperator):
     template_ext = ()
     ui_color = '#ededed'
 
-    @apply_defaults
     def __init__(self,
                  job_name='aws_glue_default_job',
                  job_desc='AWS Glue Job with Airflow',
