@@ -1,6 +1,5 @@
-from airflow.hooks.base_hook import BaseHook
+from airflow.hooks.base import BaseHook
 from airflow.models import BaseOperator
-from airflow.utils import apply_defaults
 from airflow.exceptions import AirflowException
 from botocore.config import Config
 
@@ -12,7 +11,6 @@ import base64
 class ExecuteLambdaOperator(BaseOperator):
     template_fields = ('additional_payload',)
 
-    @apply_defaults
     def __init__(
         self,
         lambda_function_name,
